==> hazelcast-all-3.0.2-sources.jar: com/hazelcast/util/executor/SingleExecutorThreadFactory.java <==
/*
 * Copyright (c) 2008-2013, Hazelcast, Inc. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.hazelcast.util.executor;

import com.hazelcast.instance.OutOfMemoryErrorDispatcher;

/**
 * @author mdogan 1/10/13
 */
public final class SingleExecutorThreadFactory extends AbstractExecutorThreadFactory {

    private final String threadName;

    public SingleExecutorThreadFactory(ThreadGroup threadGroup, ClassLoader classLoader, String threadName) {
        super(threadGroup, classLoader);
        this.threadName = threadName;
    }

    protected Thread createThread(Runnable r) {
        return new ManagedThread(r);
    }

    private class ManagedThread extends Thread {

        public ManagedThread(Runnable target) {
            super(threadGroup, target, threadName);
        }

        public void run() {
            try {
                super.run();
            } catch (OutOfMemoryError e) {
                OutOfMemoryErrorDispatcher.onOutOfMemory(e);
            }
        }
    }
}

==> hazelcast-all-3.6.2-sources.jar: com/hazelcast/util/executor/SingleExecutorThreadFactory.java <==
/*
 * Copyright (c) 2008-2016, Hazelcast, Inc. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.hazelcast.util.executor;

import com.hazelcast.instance.HazelcastThreadGroup;

public final class SingleExecutorThreadFactory extends AbstractExecutorThreadFactory {

    private final String threadName;

    public SingleExecutorThreadFactory(ThreadGroup threadGroup, ClassLoader classLoader, String threadName) {
        super(threadGroup, classLoader);
        this.threadName = threadName;
    }

    public SingleExecutorThreadFactory(HazelcastThreadGroup threadGroup, String threadName) {
        super(threadGroup.getInternalThreadGroup(), threadGroup.getClassLoader());
        this.threadName = threadName;
    }

    @Override
    protected Thread createThread(Runnable r) {
        return new ManagedThread(r);
    }

    private class ManagedThread extends HazelcastManagedThread {

        public ManagedThread(Runnable target) {
            super(threadGroup, target, threadName);
        }
    }
}
